//---------------------------------------------------------------------------
// Copyright 1997 Andreas Huennebeck
//
// $Source: /home/ah/CvsTree/daten/src/include/AH/Etech/Impedance.h,v $
// $Id: Impedance.h,v 1.8 2001/10/05 23:44:27 ah Exp $
//
//---------------------------------------------------------------------------

#ifndef ETECH_IMPEDANCE_H	// prevent multiple includes
#define ETECH_IMPEDANCE_H

// --- necessary includes ---

#include <AH/Config/Platform.h>
#include <AH/Etech/PhysUnit.h>

USING_NAMESPACE(Ah)

// --- types and classes ---

BEGIN_NAMESPACE(Ah)

/// represents an electrical impedance
/**
 {\tt Impedance} represents an electrical impedance which can be used both in
 DC (direct current) and in AC (alternate current) applications.
 */
class Impedance: public PhysUnitCplx
{
  public:
    /// constructor
    Impedance(Dbl r = 0.0, Dbl i = 0.0) : PhysUnitCplx("Ohm",r,i) {}
    /// constructor
    Impedance(const Cplx &val) : PhysUnitCplx("Ohm",val) {}
    /// copy constructor
    Impedance(const Impedance& i) : PhysUnitCplx("Ohm",i.Value) {}

    /// overloaded operator + for serial circuit of two impedances
    friend Impedance operator + (const Impedance &z1, const Impedance &z2)
	{ return Impedance(z1.Value + z2.Value); }

    /// overloaded operator || for parallel circuit of two impedances
    friend Impedance operator || (const Impedance &z1, const Impedance &z2);

    /// overloaded operator - for subtraction of two impedances
    friend Impedance operator - (const Impedance &z1, const Impedance &z2)
	{ return Impedance(z1.Value - z2.Value); }

    /// overloaded operator * for multiplication of {\tt Impedance} * {\tt Dbl}
    friend Impedance operator * (const Impedance &z, Dbl k)
	{ return Impedance(z.Value * k); }
    /// overloaded operator * for multiplication of{\t Dbl} * {\tt Impedance}
    friend Impedance operator * (Dbl k, const Impedance &z)
	{ return Impedance(k * z.Value); }
    /// overloaded operator * for multiplication of {\tt Impedance} * {\tt Cplx}
    friend Impedance operator * (const Impedance &z, 
				 const Cplx &k)
	{ return Impedance(z.Value * k); }
    /// overloaded operator * for multiplication of{\t Cplx} * {\tt Impedance}
    friend Impedance operator * (const Cplx &k, 
				 const Impedance &z)
	{ return Impedance(k * z.Value); }

    /// overloaded operator / for division of {\tt Impedance} / {\tt Cplx}
    friend Impedance operator / (const Impedance &z1, 
				 const Cplx &k)
	{ return Impedance(z1.Value / k); }

    /// overloaded operator == for comparison of two Impedances
    friend bool operator == (const Impedance &z1, const Impedance& z2)
	{ return (z1.Value == z2.Value); }
    /// overloaded operator != for comparison of two Impedances
    friend bool operator != (const Impedance &z1, const Impedance& z2)
	{ return (z1.Value != z2.Value); }
    /// overloaded operator < for comparison of two Impedances
    friend bool operator < (const Impedance &z1, const Impedance& z2)
	{ return (z1.Value < z2.Value); }
    /// overloaded operator > for comparison of two Impedances
    friend bool operator > (const Impedance &z1, const Impedance& z2)
	{ return (z1.Value > z2.Value); }

}; // class Impedance


END_NAMESPACE

#endif // ETECH_IMPEDANCE_H
