//---------------------------------------------------------------------------
// Copyright 1998 Andreas Huennebeck
//
// $Source: /home/ah/CvsTree/daten/src/libAHetech/MonacorSpeakers.c,v $
// $Id: MonacorSpeakers.c,v 1.3 2001/10/05 23:44:26 ah Exp $
//
// Description: implementation of class Speaker
//
//---------------------------------------------------------------------------

static const char rcsid[] = "$Id: MonacorSpeakers.c,v 1.3 2001/10/05 23:44:26 ah Exp $ (c) 1998 Andreas Huennebeck";

// --- necessary includes ---

#include <AH/Config/Platform.h>
#include <AH/Etech/MonacorSpeakers.h>
#include <AH/Etech/IntPol.h>

// --- local stuff ---

static struct IntPolData SPP110_data[] = 
{
    {    20,	64},
    {    30,	68},
    {    40,	71},
    {    50,	72},
    {    60,	76},
    {    70,	78},
    {    80,	79},
    {    90,	80},
    {   100,	81},
    {   150,	83},
    {   200,	84},
    {   300,	87},
    {   350,	85},
    {   400,	86},
    {   440,	88},
    {   500,	86},
    {   600,	87.5},
    {   650,	86},
    {   700,	87.5},
    {   750,	88},
    {   800,	87.5},
    {   900,	84},
    {  1000,	83},
    {  1500,	85},
    {  2000,	84},
    {  2500,	86},
    {  3000,	84},
    {  3500,	86},
    {  4000,	84},
    {  5000,	86},
    {  6000,	90},
    {  6500,	92},
    {  7000,	89},
    {  7500,	86},
    {  8000,	88},
    {  9000,	84},
    {  9300,	88},
    { 10000,	84},
    { 15000,	74},
    { 20000,	60}
};

// --- class member implementation ---

IntPol* Monacor_SPP110_8::splCurve = 0; 


// default constructor
Monacor_SP45_4::Monacor_SP45_4() 
    : Speaker("Monacor SP-45/4") 
{
    Rdc = 3.3;		// Ohm
    Ls  = 0.1e-3;	// H
    Fr  = 120;		// Hz
    Qm  = 2.82; 
    Qe  = 0.68; 
    Qt  = 0.55;
    Va  = 1.5;		// liter 
    Spl = 87;		// dB/W/m
}

// default constructor
Monacor_SP45_8::Monacor_SP45_8() 
    : Speaker("Monacor SP-45/8") 
{
    Rdc = 6.5;		// Ohm
    Ls  = 0.15e-3;	// H
    Fr  = 120;		// Hz
    Qm  = 2.82; 
    Qe  = 0.68; 
    Qt  = 0.55;
    Va  = 1.5;		// liter 
    Spl = 87;		// dB/W/m
}

// default constructor
Monacor_SP60_4::Monacor_SP60_4() 
    : Speaker("Monacor SP-60/4") 
{
    Rdc = 3.3;		// Ohm
    Ls  = 0.2e-3;	// H
    Fr  = 65;		// Hz
    Qm  = 2.1; 
    Qe  = 0.64; 
    Qt  = 0.49;
    Va  = 6;		// liter 
    Spl = 85;		// dB/W/m
}

// default constructor
Monacor_SP60_8::Monacor_SP60_8() 
    : Speaker("Monacor SP-60/8") 
{
    Rdc = 6.5;		// Ohm
    Ls  = 0.3e-3;	// H
    Fr  = 65;		// Hz
    Qm  = 2.1; 
    Qe  = 0.64; 
    Qt  = 0.49;
    Va  = 6;		// liter 
    Spl = 85;		// dB/W/m
}

// default constructor
Monacor_SPP110_4::Monacor_SPP110_4() 
    : Speaker("Monacor SPP-110/4") 
{
    Rdc = 3.3;		// Ohm
    Ls  = 0.3e-3;	// H
    Fr  = 55;		// Hz
    Qm  = 2.01; 
    Qe  = 0.46; 
    Qt  = 0.37;
    Va  = 8;		// liter 
    Spl = 86;		// dB/W/m
}

// default constructor
Monacor_SPP110_8::Monacor_SPP110_8() 
    : Speaker("Monacor SPP-110/8") 
{
    Rdc = 6.5;		// Ohm
    Ls  = 0.4e-3;	// H
    Fr  = 55;		// Hz
    Qm  = 2.01; 
    Qe  = 0.46; 
    Qt  = 0.37;
    Va  = 8;		// liter 
    Spl = 86;		// dB/W/m
}

/// get acoustic power level dB/W/m at specified frequency
Dbl Monacor_SPP110_8::getSpl(Dbl freq) const
{
    if(!splCurve)
    {
	splCurve = new IntPolLog1Lin2(SPP110_data, 
			sizeof(SPP110_data)/sizeof(*SPP110_data));
    }
    return splCurve->getY(freq);
}

