//---------------------------------------------------------------------------
// Copyright 1998 Andreas Huennebeck
//
// $Source: 
// $Id: 
//
// Description: implementation of class TransistorFollower
//
//---------------------------------------------------------------------------

static const char rcsid[] = "$Id: TransFollow.c,v 1.4 2001/10/05 23:44:26 ah Exp $ (c) 1998 Andreas Huennebeck";

// --- necessary includes ---

#include <AH/Config/Platform.h>
#include <AH/Etech/TransFollow.h>
#include <AH/Etech/Transistor.h>
#include <AH/Etech/Algo.h>
#ifdef TRACE
#   include <AH/IO/CFormat.h>
    typedef UtilCFormat Fmt;
#endif

USING_NAMESPACE(Ah)

BEGIN_NAMESPACE(Ah)

// --- local stuff ---

// --- class member implementation ---

Current TransistorFollower::getIload(const Voltage& Us)
{
    if (Us == cashedUs) return cashedIc;

    const double eps = 1e-6;
    int dir = 0;
    double Ube = 2;	// start value
    double dUbe = 1;	// initial inc/decrement
    Current Ic(0);
#ifdef TRACE
    Fmt dfm("%9.6");
    Fmt ifm("%4d");
#endif

    int counts;
    for (counts = 0; counts < 100; counts++)
    {
	Ic = T.getIout(Voltage(Ube));
	Voltage curUs(Ube + Ic * Load);

#ifdef TRACE
	cerr << ifm << counts 
	     << ": Ic=" << dfm << Ic 
	     << " Ube=" << dfm << Ube 
	     << " Us=" << dfm << Us << "/" << dfm << curUs 
	     << " d=" << dfm << abs(curUs - Us) << endl;
#endif

	if (abs(curUs - Us) < eps) break;
	if (curUs < Us)
	{
	    if (-1 == dir) dUbe /= 2;
	    dir = 1;
	    Ube += dUbe;
	}
	else
	{
	    if (1 == dir) dUbe /= 2;
	    dir = -1;
	    Ube -= dUbe;
	}
    }
    
#ifdef TRACE
    cerr << "EmitterFollower::getIc(" << Us << "): " << counts 
	 << "iterations" << endl;
#endif

    cashedUs = Us;
    cashedIc = Ic;
    return Ic;
}


Voltage TransistorFollower::getUload(const Voltage& Us)
{
    return Load * getIload(Us); 
}

// --- friend functions ---

// --- overloaded operators ---

END_NAMESPACE
